local quickreply = {}
quickreply.channel = gkini.ReadInt("QuickReply", "channel", 1)
quickreply.version = '1.2.1'

--## Choco ##--

local last_chat_name = nil --name of last person (excludes player) to chat to designated channel
local last_sector_name = nil --name of last person (excludes player) to use sector chat
local recent_channel = nil --channel id of most recent non-active channel to have activity 

--handles chat to non-active channel events
local function doChat(data)
	recent_channel = data.channelid
	if data.channelid == quickreply.channel then last_chat_name = data.name end
end

--handles chat to active channel events
local function doActiveChat(data)
	if data.channelid == quickreply.channel and data.name ~= GetPlayerName() then last_chat_name = data.name end
end

--handles sector chat events
local function doSectorChat(data)
	if data.name ~= GetPlayerName() then last_sector_name = data.name end
end

--maps events with function to call
quickreply.events = {
	CHAT_MSG_CHANNEL = doChat,
	CHAT_MSG_CHANNEL_EMOTE = doChat,
	CHAT_MSG_CHANNEL_ACTIVE = doActiveChat,
	CHAT_MSG_CHANNEL_ACTIVE_EMOTE = doActiveChat,
	CHAT_MSG_SECTOR = doSectorChat,
	CHAT_MSG_SECTOR_EMOTE = doSectorChat,
}

function quickreply:OnEvent(event, data)
	if quickreply.events[event] then quickreply.events[event](data) end
end

quickreply.inputs = {setch=true, replytarget=true, replysector=true, replychannel=true, recentchannel=true}
function quickreply:input(args)
	args = args or {}
	local command = args[1] and args[1]:lower()
	
	if quickreply.inputs[command] then
		table.remove(args, 1)
		quickreply[command](self,args)
	else return quickreply:help() end
end

function quickreply:setch(channelid)
	local ch = tonumber(channelid)
	
	if channelid:lower() == "active" then ch = GetActiveChatChannel() end
	
	if ch then --verify valid number
		quickreply.channel = ch
		gkini.WriteInt("QuickReply", "channel", quickreply.channel)
		print('\127ffffffQuickReply monitoring channel '..quickreply.channel)
	else print('\127ffffffYou must specify a channel, currently monitoring '..quickreply.channel) end 
end

function quickreply:replytarget()
	local node,obj = radar.GetRadarSelectionID()
	
	if node and obj then
		gkinterface.GKProcessCommand("prompt \'msg \""..substitute_vars("%target%").."\" \'")
	else print'\127ffffffYou do not have a target' end
end

function quickreply:replysector()
	if last_sector_name then
		gkinterface.GKProcessCommand("prompt \'msg \""..last_sector_name.."\" \'")
	else print'\127ffffffNo one has used sector chat' end
end

function quickreply:replychannel()
	if last_chat_name then
		gkinterface.GKProcessCommand("prompt \'msg \""..last_chat_name.."\" \'")
	else print('\127ffffffNo one has chatted to '..quickreply.channel) end
end

function quickreply:recentchannel()
	local active_channel = GetActiveChatChannel()
	
	if recent_channel and recent_channel~=active_channel then
		JoinChannel{recent_channel}
		recent_channel = active_channel
	else print'\127ffffffNo one has chatted to a non-active channel' end
end

function quickreply:help()
	print('\127ffffff'..'QuickReply v'..quickreply.version..'   Available commands:'..
	'\n\t/quickreply setch \1270000ffnumber\127o - sets channel monitored to \1270000ffnumber\127o'..
	'\n\t/reply_target - Send a PM to current target'..
	'\n\t/reply_sector - Send a PM to the last person to use sector chat'..
	'\n\t/reply_channel - Send a PM to the last person to chat to the monitored channel'..
	'\n\t/recent_channel - Switch to the non-active channel with the most recent activity')
end

RegisterEvent(quickreply, "CHAT_MSG_CHANNEL")
RegisterEvent(quickreply, "CHAT_MSG_CHANNEL_ACTIVE")
RegisterEvent(quickreply, "CHAT_MSG_SECTOR")
RegisterEvent(quickreply, "CHAT_MSG_SECTOR_EMOTE")
RegisterUserCommand("quickreply", quickreply.input)
RegisterUserCommand("reply_target", quickreply.replytarget)
RegisterUserCommand("reply_sector", quickreply.replysector)
RegisterUserCommand("reply_channel", quickreply.replychannel)
RegisterUserCommand("recent_channel", quickreply.recentchannel)